{% load url from future %}
<div id="hijacked-warning" >
    <span style="padding-top: 4px; float: left;"><b>You're currently working on behalf of {{ request.user }}.</b></span>
    <span style="float: right; margin-right: 15px;"><a href="{% url 'release_hijack' %}" class="django-hijack-button">release {{ request.user }}</a>
    <a href="{% url 'disable_hijack_warning' %}?next={{ request.path_info }}" class="django-hijack-button">hide</a></span>
</div>
